@@ -32,7 +32,7 @@
 
 /* #undef RDK_BUILD_AVALON_SUPPORT */
 
-/* #undef RDK_BUILD_INCHI_SUPPORT */
+#define RDK_BUILD_INCHI_SUPPORT
 
 #define RDK_BUILD_SLN_SUPPORT
 
